''' swaps: { "name": "Phosphorus", "alternate names": [], "measures": { "mass + mass equivalents": { "per package": { "is equivalent": "no", "listed": [ "1368.000", "mg" ], "grams": { "decimal string": "1.368", "fraction string": "171/125" } } } }, "unites": [] } for: "essential nutrients": { "essential": {}, "natures": [], "measures": {}, "unites": [] } { "name": "Phosphorus", "alternate names": [], "measures": { "mass + mass equivalents": { "per package": { "is equivalent": "no", "listed": [ "1368.000", "mg" ], "grams": { "decimal string": "1.368", "fraction string": "171/125" } } } }, "unites": [] } '''